<TS language="lt" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>Apie Gridcoin</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Sukurti naują adresą</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Naujas</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopijuoti esamą adresą į mainų atmintį</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopijuoti</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Registruoti praneši&amp;mą</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Patikrinti žinutę</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Ištrinti pasirinktą adresą iš sąrašo</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Trinti</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopijuoti ž&amp;ymę</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Keisti</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Žymė</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresas</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nėra žymės)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Slaptafrazės dialogas</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Įvesti slaptafrazę</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nauja slaptafrazė</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Pakartokite naują slaptafrazę</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Užšifruoti piniginę</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Ši operacija reikalauja jūsų piniginės slaptafrazės jai atrakinti.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Atrakinti piniginę</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Pakeisti slaptafrazę</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Įveskite seną ir naują piniginės slaptafrazes.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Patvirtinkite piniginės užšifravimą</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Ar tikrai norite šifruoti savo piniginę?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Piniginė užšifruota</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Nepavyko užšifruoti piniginės</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Dėl vidinės klaidos nepavyko užšifruoti piniginės.Piniginė neužšifruota.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Įvestos slaptafrazės nesutampa.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Nepavyko atrakinti piniginės</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Neteisingai įvestas slaptažodis piniginės iššifravimui.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Piniginės slaptažodis sėkmingai pakeistas.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Dėmesio: įjungtas Caps Lock klavišas!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Piniginė</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Apžvalga</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Rodyti piniginės bendrą apžvalgą</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Siųsti</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Gauti</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Apžvelgti sandorių istoriją</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Išeiti</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Išjungti programą</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Parinktys...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Rodyti / Slėpti</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Užšifruoti piniginę...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Keisti slaptafrazę...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Pakeisti slaptafrazę naudojamą piniginės užšifravimui</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Atrakinti piniginę</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>Užrakinti piniginę</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Pasirašyti ži&amp;nutę...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Tikrinti žinutę...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Derinimo langas</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Atverti derinimo ir diagnostikos konsolę</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Failas</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nustatymai</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <source>[testnet]</source>
        <translation>[testavimotinklas]</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Atnaujinta</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Vejamasi...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Sandoris nusiųstas</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Ateinantis sandoris</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Piniginė &lt;b&gt;užšifruota&lt;/b&gt; ir šiuo metu &lt;b&gt;užrakinta&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Tinklo įspėjimas</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Kiekis:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Baitai:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Suma:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Mokestis:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Po mokesčio:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Grąža:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Suma</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Patvirtinimai</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Patvirtintas</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Žymė</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresas</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopijuoti adresą</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopijuoti žymę</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopijuoti sumą</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>taip</translation>
    </message>
    <message>
        <source>no</source>
        <translation>ne</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nėra žymės)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Keisti adresą</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>Ž&amp;ymė</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresas</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Naujas gavimo adresas</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Naujas siuntimo adresas</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Keisti gavimo adresą</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Keisti siuntimo adresą</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Įvestas adresas „%1“ jau yra adresų knygelėje.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Nepavyko atrakinti piniginės.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Naujo rakto generavimas nepavyko.</translation>
    </message>
</context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>version</source>
        <translation>versija</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Parinktys</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Pagrindinės</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Tinklas</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Persiųsti prievadą naudojant &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Prievadas:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Tarpinio serverio preivadas (pvz, 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Uždarant langą neuždaryti programos. Kai ši parinktis įjungta, programa bus uždaryta tik pasirinkus  meniu komandą Baigti.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Rodyti adresus sandorių sąraše</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Langas</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Po programos lango sumažinimo rodyti tik programos ikoną.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;M sumažinti langą bet ne užduočių juostą</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>&amp;Sumažinti uždarant</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Rodymas</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Naudotojo sąsajos &amp;kalba:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Vienetai, kuriais rodyti sumas:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Rodomų ir siunčiamų monetų kiekio matavimo vienetai</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Gerai</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Atšaukti</translation>
    </message>
    <message>
        <source>default</source>
        <translation>numatyta</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Nurodytas tarpinio serverio adresas negalioja.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Forma</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Galimi:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Jūsų dabartinis balansas, kurį galite išleisti</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Nepribrendę:</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Piniginė</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Viso:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Jūsų balansas</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>Message:</source>
        <translation>Žinutė:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Suma:</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>nėra</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Kliento versija</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informacija</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Paleidimo laikas</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Prisijungimų kiekis</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Blokų grandinė</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Dabartinis blokų skaičius</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Paskutinio bloko laikas</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Atverti</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>Išvalyti</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konsolė</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Viso:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Derinimo žurnalo failas</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Išvalyti konsolę</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Komandinės eilutės parametrai</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Kliento pavadinimas</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Siųsti monetas</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Nepakanka lėšų</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Kiekis:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Baitai:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Suma:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Mokestis:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Po mokesčio:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Siųsti keliems gavėjams vienu metu</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>&amp;A Pridėti gavėją</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Išvalyti &amp;viską</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Patvirtinti siuntimo veiksmą</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Siųsti</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopijuoti sumą</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Patvirtinti monetų siuntimą</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>Negaliojantis gavėjo adresas. Patikrinkite.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Apmokėjimo suma turi būti didesnė nei 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Suma viršija jūsų balansą.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Pridėjus sandorio mokestį %1 bendra suma viršija jūsų balansą.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nėra žymės)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Su&amp;ma:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Mokėti &amp;gavėjui:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Žinutė:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>Ž&amp;ymė:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Įvesti adresą iš mainų atminties</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Įveskite žymę šiam adresui kad galėtumėte įtraukti jį į adresų knygelę</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Pasirašyti žinutę</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Įvesti adresą iš mainų atminties</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Įveskite pranešimą, kurį norite pasirašyti čia</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Registruoti praneši&amp;mą</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Išvalyti &amp;viską</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Patikrinti žinutę</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Spragtelėkite "Registruotis žinutę" tam, kad gauti parašą</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Įvestas adresas negalioja.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Prašom patikrinti adresą ir bandyti iš naujo.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Piniginės atrakinimas atšauktas.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Žinutės pasirašymas nepavyko.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Žinutė pasirašyta.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Nepavyko iškoduoti parašo.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Prašom patikrinti parašą ir bandyti iš naujo.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Parašas neatitinka žinutės.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Žinutės tikrinimas nepavyko.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Žinutė patikrinta.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Atidaryta iki %1</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/neprisijungęs</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/nepatvirtintas</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 patvirtinimų</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Būsena</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, transliavimas dar nebuvo sėkmingas</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Šaltinis</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Nuo</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nežinomas</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Kam</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>savo adresas</translation>
    </message>
    <message>
        <source>label</source>
        <translation>žymė</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Kreditas</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>nepriimta</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Debitas</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Sandorio mokestis</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Neto suma</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Žinutė</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Komentaras</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Suma</translation>
    </message>
    <message>
        <source>true</source>
        <translation>tiesa</translation>
    </message>
    <message>
        <source>false</source>
        <translation>netiesa</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Sandorio detalės</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Šis langas sandorio detalų aprašymą</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipas</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresas</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Suma</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Atidaryta iki %1</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Patvirtinta (%1 patvirtinimai)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Išgauta bet nepriimta</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Gauta su</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Gauta iš</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Siųsta </translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Mokėjimas sau</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>nepasiekiama</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Sandorio būklė. Užvedus pelės žymeklį ant šios srities matysite patvirtinimų skaičių.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Sandorio gavimo data ir laikas</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Sandorio tipas.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Sandorio paskirties adresas</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Suma pridėta ar išskaičiuota iš balanso</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Šiandien</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Ši? savait?</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Š? m?nes?</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Paskutin? m?nes?</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Šiais metais</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Intervalas...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Gauta su</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Išsi?sta</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Skirta sau</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Išgauta</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Kita</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Minimali suma</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopijuoti adresą</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopijuoti žymę</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopijuoti sumą</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Taisyti žymę</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Rodyti sandorio detales</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Patvirtintas</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipas</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Žymė</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresas</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Suma</translation>
    </message>
    <message>
        <source>to</source>
        <translation>skirta</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Usage:</source>
        <translation>Naudojimas:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Komand? s?rašas</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Suteikti pagalba komandai</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>?sp?jimas: -paytxfee yra nustatytas per didelis. Tai sandorio mokestis, kur? tur?site mok?ti, jei si?site sandor?.</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Neteisinga suma -paytxfee=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Neteisingas proxy adresas: '%s'</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation> wallet.dat pakrovimo klaida,  wallet.dat sugadintas</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation> wallet.dat pakrovimo klaida</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Užkraunami adresai...</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Nepavyko susieti šiame kompiuteryje prievado %s (bind returned error %d, %s)</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Neteisinga suma</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Nepakanka lėšų</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Įkeliamas blokų indeksas...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Užkraunama piniginė...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Negalima parašyti įprasto adreso</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Peržiūra</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Įkėlimas baigtas</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
</context>
</TS>